@@ -122,7 +122,7 @@ def create_tex_file(filenames, working_dir):
   }
 \usepackage[T1]{fontenc}
 \usepackage[utf8]{inputenc}
-\usepackage{minted} 
+\usepackage{minted}
 
 \setlength{\parindent}{0cm}
 \renewcommand{\familydefault}{\sfdefault}
@@ -160,7 +160,7 @@ def create_tex_file(filenames, working_dir):
 
 def create_pdf(filenames, working_dir, silent=False):
 
-    print(f"Creating LaTeX code...")
+    print("Creating LaTeX code...")
     tex_code, scoring = create_tex_file(filenames, working_dir)
 
     if not tex_code:
@@ -198,7 +198,7 @@ def create_pdf(filenames, working_dir, silent=False):
 def main():
 
     parser = argparse.ArgumentParser()
-    parser.add_argument('--input_folder', default='.')
+    parser.add_argument('--input-folder', default='.')
     parser.add_argument('source_files', nargs='+')
     parser.add_argument('--language', default='java')
     parser.add_argument('--silent', action='store_true')
